import 'package:dcoupon_sdk_flutter_package/src/config_reader.dart';
import 'package:dcoupon_sdk_flutter_package/src/core/device_info.dart';
import 'package:dcoupon_sdk_flutter_package/src/data/helpers/authorization_helper.dart';
import 'package:dcoupon_sdk_flutter_package/src/utils/constants.dart';
import 'package:dcoupon_sdk_flutter_package/src/utils/enum_helper.dart';

const String API_PATH_NAME = '/dcoupon-ocr-services';

const Map<String, String> URLS_BY_ENVIRONMENT = {
  'dev': 'https://services-dev.dcoupon.com',
  'dcoupon.eu': 'https://services.dcoupon.eu',
  'dcoupon-latam.com': 'https://services-latam.dcoupon.com',
  'dcoupon.com': 'https://services.dcoupon.com'
};

class OCRServicesApiHelper {
  static Map<String, dynamic> buildHeaders({
    bool userAuthentication = true,
  }) {
    var headers = <String, dynamic>{};

    final currentDateFormatted = AuthorizationHelper.getCurrentDateFormatted();
    headers[Constants.HEADER_AUTH_METHOD] =
        EnumHelper.enumToString(AuthMethod.SIGNATURE);
    headers[Constants.HEADER_AUTH_TIMESTAMP] = currentDateFormatted;
    headers[Constants.HEADER_AUTH_APIKEY] = ConfigReader.dcouponSDKOptions.clientApiToken;
    headers[Constants.HEADER_AUTH_SIGNATURE] =
        AuthorizationHelper.getAuthSignature(currentDateFormatted);

    if (userAuthentication) {
      headers[Constants.HEADER_USER_JWT] = ConfigReader.userJwt;
    }

    return headers;
  }

  static String getEndpointUrl() {
    if (DevicePlatform.isWeb && ConfigReader.dcouponSDKOptions.webOrigin != null) {
      return ConfigReader.dcouponSDKOptions.webOrigin!;
    }
    return URLS_BY_ENVIRONMENT[ConfigReader.dcouponSDKOptions.clientDomain]!;
  }

  static String getS3FilePresignedUrl() {
    const methodPath = '/files/tars/upload-presigned-url';
    return getEndpointUrl() + API_PATH_NAME + methodPath;
  }

}
