import 'package:dcoupon_sdk_flutter_package/src/core/error/failures.dart';
import 'package:dartz/dartz.dart';

import 'package:dcoupon_sdk_flutter_package/src/data/datasources/receipt_remote_data_source.dart';
import 'package:dcoupon_sdk_flutter_package/src/domain/repositories/receipt_repository.dart';

class ReceiptRepositoryImpl implements ReceiptRepository {
  final ReceiptRemoteDataSource remoteDataSource;

  ReceiptRepositoryImpl({
    required this.remoteDataSource,
  });

  @override
  Future<Either<Failure, dynamic>> getS3FilePresignedUrl() async {
    return await remoteDataSource.getS3FilePresignedUrl();
  }

  @override
  Future<Either<Failure, dynamic>> uploadPresignedUrlFile({
    required List<int> fileBytes,
    required String presignedUrl,
    required Map<String, dynamic> presignedUrlFields,
  }) async {
    return await remoteDataSource.uploadPresignedUrlFile(
      fileBytes: fileBytes,
      presignedUrl: presignedUrl,
      presignedUrlFields: presignedUrlFields,
    );
  }

  @override
  Future<Either<Failure, dynamic>> getUserReceipts({
    int? start,
    int? limit,
    String? sortBy,
    List<String>? companyTokens,
    List<String>? retailerTokens,
  }) async {
    return await remoteDataSource.getUserReceipts(
      start: start,
      limit: limit,
    );
  }
}
