import 'package:dartz/dartz.dart';
import 'package:dcoupon_sdk_flutter_package/src/core/error/failures.dart';
import 'package:dcoupon_sdk_flutter_package/src/core/usecases/usecase.dart';
import 'package:dcoupon_sdk_flutter_package/src/domain/repositories/receipt_repository.dart';
import 'package:equatable/equatable.dart';

class ReceiptUploadS3File
    implements UseCase<dynamic, ReceiptUploadS3FileParams> {
  final ReceiptRepository repository;

  ReceiptUploadS3File(this.repository);

  @override
  Future<Either<Failure, dynamic>> call(
      ReceiptUploadS3FileParams params) async {
    return await repository.uploadPresignedUrlFile(
      fileBytes: params.fileBytes,
      presignedUrl: params.presignedUrl,
      presignedUrlFields: params.presignedUrlFields,
    );
  }
}

class ReceiptUploadS3FileParams extends Equatable {
  final List<int> fileBytes;
  final String presignedUrl;
  final Map<String, dynamic> presignedUrlFields;

  ReceiptUploadS3FileParams({
    required this.fileBytes,
    required this.presignedUrl,
    required this.presignedUrlFields,
  });

  @override
  List<Object?> get props => [
        fileBytes,
        presignedUrl,
        presignedUrlFields,
      ];
}
