import 'package:dartz/dartz.dart';
import 'package:dcoupon_sdk_flutter_package/src/core/error/failures.dart';
import 'package:dcoupon_sdk_flutter_package/src/core/usecases/usecase.dart';
import 'package:dcoupon_sdk_flutter_package/src/domain/repositories/redemption_repository.dart';
import 'package:equatable/equatable.dart';

class RedemptionGetCashbackRedemptionDetail
    implements UseCase<dynamic, RedemptionGetCashbackRedemptionDetailParams> {
  final RedemptionRepository repository;

  RedemptionGetCashbackRedemptionDetail(this.repository);

  @override
  Future<Either<Failure, dynamic>> call(
      RedemptionGetCashbackRedemptionDetailParams params) async {
    return await repository.getCashbackRedemptionDetail(
      redemptionId: params.redemptionId,
      gmtTimeZoneOffset: params.gmtTimeZoneOffset,
    );
  }
}

class RedemptionGetCashbackRedemptionDetailParams extends Equatable {
  final String redemptionId;
  final int gmtTimeZoneOffset;

  RedemptionGetCashbackRedemptionDetailParams({
    required this.redemptionId,
    required this.gmtTimeZoneOffset,
  });

  @override
  List<Object?> get props => [
        redemptionId,
        gmtTimeZoneOffset,
      ];
}
